#include <bits/stdc++.h>

#ifdef __LOCAL__
    #include "Lgrader.cpp"
#else
    #include "coins.h"
#endif // __LOCAL__

using namespace std;

const int MAXN = 3e6 + 50;

struct SegmentTreeState
{
    int compareValue, numberOfHeavyCoins;
    bool isUnknown;

    SegmentTreeState(){}
    SegmentTreeState(int  compareValue, int numberOfHeavyCoins, bool isUnknown)
        :compareValue(compareValue), numberOfHeavyCoins(numberOfHeavyCoins), isUnknown(isUnknown){}
};
struct SegmentTree
{
    int n;
    SegmentTreeState tree[MAXN];

    SegmentTree(){}
    SegmentTree(int n)
    {
        this->n = n;
    }

    void Build()
    {
        buildInternal(1, 0, n-1);
    }

    int GetHeavySize()
    {
        return tree[1].numberOfHeavyCoins;
    }
    void Recalculate(int node, int l, int r)
    {
        SegmentTreeState left = tree[node*2], right = tree[node*2 + 1];

        if (left.isUnknown == false && right.isUnknown == false)
        {
            tree[node].isUnknown = false;
            tree[node].numberOfHeavyCoins = left.numberOfHeavyCoins + right.numberOfHeavyCoins;
            if (left.numberOfHeavyCoins > right.numberOfHeavyCoins)
                tree[node].compareValue = 1;

            if (left.numberOfHeavyCoins < right.numberOfHeavyCoins)
                tree[node].compareValue = -1;

            if (left.numberOfHeavyCoins == right.numberOfHeavyCoins)
                tree[node].compareValue = 0;
            return;
        }

        vector <int> a, b;
        int mid = (l+r)/2;
        a.reserve(mid - l + 1);
        b.reserve(r - mid);

        for (int i = l; i <= mid; i++)
            a.push_back(i);

        for (int i = mid+1; i <= r; i++)
            b.push_back(i);

        if (left.isUnknown == true && right.isUnknown == false)
        {
            tree[node].isUnknown = false;
            int res = weigh(a, b);
            tree[node].compareValue = res;
            if (res == -1)
            {
                tree[node].numberOfHeavyCoins = right.numberOfHeavyCoins;
            }
            if (res == 1)
            {
                tree[node].numberOfHeavyCoins = left.numberOfHeavyCoins + right.numberOfHeavyCoins;
            }
            if (res == 0)
            {
                tree[node].numberOfHeavyCoins = right.numberOfHeavyCoins*2;
            }

            return;
        }

        if (left.isUnknown == false && right.isUnknown == true)
        {
            tree[node].isUnknown = false;
            int res = weigh(a, b);
            tree[node].compareValue = res;
            if (res == -1)
            {
                tree[node].numberOfHeavyCoins = left.numberOfHeavyCoins + right.numberOfHeavyCoins;
            }
            if (res == 1)
            {
                tree[node].numberOfHeavyCoins = left.numberOfHeavyCoins;
            }
            if (res == 0)
            {
                tree[node].numberOfHeavyCoins = left.numberOfHeavyCoins*2;
            }

            return;
        }

        if (left.isUnknown == true && right.isUnknown == true)
        {
            tree[node].isUnknown = true;
            int res = weigh(a, b);
            tree[node].compareValue = res;
            if (res == -1)
            {
                tree[node].numberOfHeavyCoins = right.numberOfHeavyCoins;
                tree[node].isUnknown = false;
            }
            if (res == 1)
            {
                tree[node].numberOfHeavyCoins = left.numberOfHeavyCoins;
                tree[node].isUnknown = false;
            }
            if (res == 0)
            {
                tree[node].numberOfHeavyCoins = left.numberOfHeavyCoins + right.numberOfHeavyCoins;
            }

            return;
        }
    }
    void calcLeaves(int node, int l, int r)
    {
        int cmp = weigh({l}, {r});
        tree[node].compareValue = cmp;
        if (cmp == -1)
        {
            tree[node].numberOfHeavyCoins = 1;
            tree[node].isUnknown = false;
        }

        if (cmp == 1)
        {
            tree[node].numberOfHeavyCoins = 1;
            tree[node].isUnknown = false;
        }

        if (cmp == 0)
        {
            tree[node].numberOfHeavyCoins = 2;
            tree[node].isUnknown = true;
        }
    }
    void buildInternal(int node, int l, int r)
    {
        if (l == r)
        {
            tree[node] = SegmentTreeState(0, 0, true);
            return;
        }

        buildInternal(node*2, l, (l+r)/2);
        buildInternal(node*2+1, (l+r)/2 + 1, r);

        if (l == r-1)
        {
            calcLeaves(node, l, r);
            return;
        }
        Recalculate(node, l, r);
    }
};

int findFirstHeavy(int n)
{
    int l = 0, r = n-1, mid, ans = -1;
    while (l < r)
    {
        mid = (l+r)/2;
        vector <int> a, b;
        a.reserve(mid-l + 1);
        b.reserve(r-mid);
        for (int i = l; i <= mid; i++)
            a.push_back(i);
        for (int i = mid+1; i <= r; i++)
            b.push_back(i);

        int res = weigh(a, b);
        if (res == 0)
            r = mid;
        if (res == 1)
            r = mid;
        if (res == -1)
            l = mid+1;
    }
    return r;
}
pair <int, int> count_heavy(int k)
{
    int n = (1<<k);

    SegmentTree *tree = new SegmentTree(n);
    tree->Build();

    int heavyIndex = findFirstHeavy(n);
    return {tree->GetHeavySize(), heavyIndex};

}
