#include <iostream>
#include <algorithm>
#include <cmath>
#include <vector>

using namespace std;

#define int long long
#define maxN 100010

int sum(int x) {
    int ans = 1;
    for (int i = 2; i * i <= x; i++) {
        if (i * i == x) {
            ans += i;
            continue;
        }
        if (x % i == 0) {
            ans += x / i + i;
        }
    }
    return ans;
}


struct Vertex {
    Vertex *left;
    Vertex *right;
    int val;

    Vertex(int s = 0) : left(nullptr), right(nullptr), val(s) {
    }

    Vertex(Vertex *l, Vertex *r) : left(l), right(r), val(l->val + r->val) {

    }

};

class Tree {
public:
    vector<Vertex *> versions;
    vector<int> fg;

    Vertex *build(vector<int> &a, int l, int r) {
        if (l == r)
            return new Vertex(a[l]);

        int mid = (l + r) / 2;
        auto left = build(a, l, mid);
        auto right = build(a, mid + 1, r);
        return new Vertex(left, right);
    }

    int get(Vertex *cur, int tl, int tr, int l, int r) {
        if (l > r)
            return 0;
        if (tl == l and r == tr)
            return cur->val;
        int mid = (tl + tr) / 2;
        return get(cur->left, tl, mid, l, min(r, mid)) + get(cur->right, mid + 1, tr, max(l, mid + 1), r);
    }


    Vertex *update(Vertex *v, int tl, int tr, int pos, int newVal) {
        if (tl == tr) {
            return new Vertex(v->val + newVal);
        } else {
            int tm = (tl + tr) / 2;
            Vertex *l;
            Vertex *r;
            if (pos <= tm)
                l = update(v->left, tl, tm, pos, newVal), r = v->right;
            else
                r = update(v->right, tm + 1, tr, pos, newVal), l = v->left;
            return new Vertex(l, r);
        }
    }

    Tree(vector<int> &a) {
        fg = a;
        versions.push_back(build(a, 0, a.size() - 1));
    }

    int get(int l, int r, int v = -1) {
        if (v == -1) {
            return get(versions.back(), 0, fg.size() - 1, l, r);
        } else
            return get(versions[v], 0, fg.size() - 1, l, r);
    }

    void update(int pos, int newVal, bool save = true) {
        if (!save)
            versions.back() = update(versions.back(), 0, fg.size() - 1, pos, newVal);
        else
            versions.push_back(update(versions.back(), 0, fg.size() - 1, pos, newVal));
    }
};


signed main() {
    vector<int> v(maxN, 0);
    for (int i = 2; i < v.size(); i++)
        v[i] = sum(i);

    vector<int> z(maxN, 0);
    Tree t(z);
    for (int i = 0; i < v.size(); i++) {
        t.update(0, 1);
        t.update(v[i], -1, false);
    }
    cout<<1/0<<endl;
    int q = 0;
    cin >> q;
    for (int i = 0; i < q; i++) {
        int a, b, c;
        cin >> a >> b >> c;
        int r = t.get(0, c - 1, b+1);
        int l = t.get(0, c - 1, a+1);
        cout << r - l << endl;
    }
}