#include <iostream>
#include <algorithm>
#include <cmath>
#include <vector>

using namespace std;

#define int long long
#define maxN 100010
#define endl "\n"

int sum(int x) {
    if (x == 1)
        return 0;

    int ans = 1;
    for (int i = 2; i * i <= x; i++) {
        if (i * i == x) {
            ans += i;
            continue;
        }
        if (x % i == 0) {
            ans += x / i + i;
        }
    }
    return ans;
}


struct Vertex {
    Vertex *left;
    Vertex *right;
    int val;

    Vertex(int s = 0) : left(nullptr), right(nullptr), val(s) {
    }

    Vertex(Vertex *l, Vertex *r) : left(l), right(r), val(l->val + r->val) {

    }

};

class Tree {
public:
    vector<Vertex *> versions;
    int a;

    Vertex *build(int l, int r) {
        if (l == r)
            return new Vertex(0);

        int mid = (l + r) / 2;
        auto left = build(l, mid);
        auto right = build(mid + 1, r);
        return new Vertex(left, right);
    }

    int get(Vertex *cur, int tl, int tr, int l, int r) {
        if (l > r)
            return 0;
        if (tl == l and r == tr)
            return cur->val;
        int mid = (tl + tr) / 2;
        return get(cur->left, tl, mid, l, min(r, mid)) + get(cur->right, mid + 1, tr, max(l, mid + 1), r);
    }


    Vertex *update(Vertex *v, int tl, int tr, int pos, int newVal) {
        if (tl == tr) {
            return new Vertex(v->val + newVal);
        } else {
            int tm = (tl + tr) / 2;
            Vertex *l;
            Vertex *r;
            if (pos <= tm)
                l = update(v->left, tl, tm, pos, newVal), r = v->right;
            else
                r = update(v->right, tm + 1, tr, pos, newVal), l = v->left;
            return new Vertex(l, r);
        }
    }

    Tree(int a) {
        this->a = a;
        versions.push_back(build(0, a - 1));
    }

    int get(int l, int r, int v) {
        return get(versions[v], 0, a - 1, l, r);
    }

    void update(int pos, int newVal, bool save = true) {
        if (!save)
            versions.back() = update(versions.back(), 0, a - 1, pos, newVal);
        else
            versions.push_back(update(versions.back(), 0, a - 1, pos, newVal));
    }
};


signed main() {
    Tree t(maxN);
    for (int i = 0; i < maxN; i++) {
        t.update(0, 1);
        t.update(sum(i + 1), -1, false);
    }
//    cout<<1/0<<endl;
    int q = 0;
    cin >> q;
    for (int i = 0; i < q; i++) {
        int a, b, c;
        scanf("%lld%lld%lld", &a, &b, &c);
        int r = t.get(0, c, b);
        int l = t.get(0, c, a - 1);
        printf("%lld \n", r - l);
    }
}
//0 1 1 3 1 6 1 7 4 8 1   16 1 10 9 15 1 21 1 22    11 14 1 36 6 16 13 28 1 42 6